@@ -5,26 +5,29 @@
 #' @param data.test (Optional) A model testing dataset (same format as data.train)
 #' @param max.levels A number indicating the maximum number of levels considered for the tree.
 #' @param train.p A number between 0 and 1 indicating what percentage of the data to use for training. This only applies when data.test is not specified by the user.
-#' @param rank.method A string indicating how to rank cues during tree construction. "m" (for marginal) means that cues will only be ranked once with the entire training dataset. "c" (conditional) means that cues will be ranked after each level in the tree with the remaining unclassified training exemplars.
+#' @param rank.method A string indicating how to rank cues during tree construction. "m" (for marginal) means that cues will only be ranked once with the entire training dataset. "c" (conditional) means that cues will be ranked after each level in the tree with the remaining unclassified training exemplars. This also means that the same cue can be used multiple times in the trees. However, the "c" method will take longer and may be prone to overfitting.
+#' @param repeat.cues A logical value indicating whether or not to allow repeated cues in the tree. Only relevant when rank.method = 'c'.
+#' @param hr.weight A number between 0 and 1 indicating how much weight to give to maximizing hits versus minimizing false alarms.
 #' @param do.cart,do.lr logical values indicating whether or not to evaluate logistic regression and/or CART on the data for comparison.
 #' @param verbose A logical value indicating whether or not to print progress reports. Can be helpful for diagnosis when the function is running slowly...
 #' @param object An optional existing FFTrees object (do not specify by hand)
-#' @importFrom stats anova predict glm as.formula formula
+#' @importFrom stats anova predict glm as.formula formula sd
 #' @return A list of length 3. The first element "tree.acc" is a dataframe containing the final statistics of all trees. The second element "cue.accuracies" shows the accuracies of all cues. The third element "tree.class.ls" is a list with n.trees elements, where each element shows the final decisions for each tree for each exemplar.
 #' @export
 #'
 
-FFTrees <- function(
-                formula = NULL,
-                data = NULL,
-                data.test = NULL,
-                train.p = 1,
-                rank.method = "m",
-                verbose = F,
-                max.levels = 4,
-                do.cart = T,
-                do.lr = T,
-                object = NULL
+FFTrees <- function(formula = NULL,
+                    data = NULL,
+                    data.test = NULL,
+                    train.p = 1,
+                    rank.method = "m",
+                    repeat.cues = TRUE,
+                    hr.weight = .5,
+                    verbose = F,
+                    max.levels = 4,
+                    do.cart = T,
+                    do.lr = T,
+                    object = NULL
 ) {
 
 # Set some global parameters
@@ -57,14 +60,30 @@ if(is.null(object) == F) {
                             data = data.train.o)
 
   cue.train <- data.train[,2:ncol(data.train)]
+
+  if(ncol(data.train) == 2) {
+
+    cue.train <- data.frame(cue.train)
+
+  }
+
   crit.train <- data.train[,1]
 
+  crit.name <- names(data.train)[1]
+
   if(is.null(data.test) == F) {
 
     data.test.o <- data.test
 
+    if(setequal(names(data.train), names(data.test)) == F) {
+
+      stop("Your training (data) and test (data.test) dataframes do not appear to have the same column names. Please fix and try again.")
+
+    }
+
     data.test <- model.frame(formula = formula,
-                             data = data.test.o)
+                             data = data.test.o,
+                             na.action = NULL)
 
     cue.test <- data.test[,2:ncol(data.test)]
     crit.test <- data.test[,1]
@@ -87,14 +106,30 @@ if(is.null(object) == T & train.p == 1) {
   data.train.o <- data
   data.train <- model.frame(formula = formula,
                             data = data.train.o)
+
   cue.train <- data.train[,2:ncol(data.train)]
+
+  if(ncol(data.train) == 2) {
+
+    cue.train <- data.frame(cue.train)
+
+  }
+
   crit.train <- data.train[,1]
 
  if(is.null(data.test) == F) {
 
+   if(setequal(names(data.train.o), names(data.test)) == F) {
+
+     stop("Your training (data) and test (data.test) dataframes do not appear to have the same column names. Please fix and try again.")
+
+   }
+
    data.test.o <- data.test
    data.test <- model.frame(formula = formula,
-                            data = data.test)
+                            data = data.test,
+                            na.action = NULL)
+
    cue.test <- data.test[,2:ncol(data.test)]
    crit.test <- data.test[,1]
 
@@ -227,7 +262,7 @@ cue.test <- fac.to.string(cue.test)
 # Check for missing or bad inputs
 {
 if(is.null(data.train) |
-   "data.frame" %in% class(data) == F) {
+   "data.frame" %in% class(data.train) == F) {
 
   stop("Please specify a valid dataframe object in data")
 
@@ -252,7 +287,7 @@ if(setequal(names(data.train), names(data.test)) == F) {
 # Non-binary DV
 if(setequal(crit.train, c(0, 1)) == F) {
 
-  stop("Warning! Your DV is not binary or logical. Convert to 0s and 1s (or FALSE and TRUE)")
+  stop("Warning! The dependent variable in your training data is either not binary or logical, or does not have variance. Convert to 0s and 1s (or FALSE and TRUE)")
 
 }
 
@@ -272,7 +307,6 @@ if(is.null(object)) {
 cue.accuracies.train <- cuerank(formula = formula,
                                 data = data.train,
                                 tree.criterion = tree.criterion,
-                                numthresh.method = numthresh.method,
                                 rounding = rounding,
                                 verbose = verbose
 )
@@ -285,20 +319,28 @@ cue.accuracies.train <- object$cue.accuracies$train
 
 }
 
-if(is.null(data.test) == F) {
+if(is.null(data.test) == F & all(is.finite(crit.test)) & is.finite(sd(crit.test))) {
+
+  if(sd(crit.test) > 0) {
 
 cue.accuracies.test <- cuerank(formula = formula,
                                 data = data.test,
                                 tree.criterion = tree.criterion,
-                                numthresh.method = numthresh.method,
                                 rounding = rounding,
                                 verbose = verbose,
                                 cue.rules = cue.accuracies.train
 )
+}
+
+  if(sd(crit.test) == 0) {
+
+    cue.accuracies.test <- NULL
+
+  }
 
 }
 
-if(is.null(data.test)) {
+if(is.null(data.test) == T | any(is.finite(crit.test)) == F | is.finite(sd(crit.test)) == F) {
 
 cue.accuracies.test <- NULL
 
@@ -315,10 +357,11 @@ if(is.null(object)) {
 tree.growth <- grow.FFTrees(formula = formula,
                             data = data.train,
                             rank.method = rank.method,
-                            numthresh.method = numthresh.method,
+                            repeat.cues = repeat.cues,
                             stopping.rule = stopping.rule,
                             stopping.par = stopping.par,
-                            max.levels = max.levels)
+                            max.levels = max.levels,
+                            hr.weight = hr.weight)
 
 tree.definitions <- tree.growth$tree.definitions
 
@@ -331,111 +374,6 @@ if(is.null(object) == F) {tree.definitions <- object$tree.definitions}
 {
 n.trees <- nrow(tree.definitions)
 
-apply.tree <- function(data,
-                       formula,
-                       tree.definitions
-                       ) {
-
-  criterion.v <- model.frame(formula = formula, data = data)[,1]
-
-  n.exemplars <- nrow(data)
-  n.trees <- nrow(tree.definitions)
-
-  levelout <- matrix(NA, nrow = n.exemplars, ncol = n.trees)
-  decision <- matrix(NA, nrow = n.exemplars, ncol = n.trees)
-
-  level.stats.ls <- vector("list", length = n.trees)
-
-  for(tree.i in 1:n.trees) {
-
-    cue.v <- unlist(strsplit(tree.definitions$cue[tree.i], ";"))
-    class.v <- unlist(strsplit(tree.definitions$classes[tree.i], ";"))
-    exit.v <- unlist(strsplit(tree.definitions$exits[tree.i], ";"))
-    threshold.v <- unlist(strsplit(tree.definitions$thresholds[tree.i], ";"))
-    direction.v <-  unlist(strsplit(tree.definitions$directions[tree.i], ";"))
-
-    n.levels <- length(cue.v)
-
-    level.stats.df.i <- data.frame(tree = tree.i,
-                                   level = 1:n.levels,
-                                   cue = cue.v,
-                                   class = class.v,
-                                   threshold = threshold.v,
-                                   direction = direction.v,
-                                   exit = exit.v)
-
-    level.stats.df.i[names(classtable(1, 1))] <- NA
-
-    for(level.i in 1:n.levels) {
-
-      cue.i <- cue.v[level.i]
-      class.i <- class.v[level.i]
-      direction.i <- direction.v[level.i]
-      exit.i <- exit.v[level.i]
-      threshold.i <- threshold.v[level.i]
-
-      cue.values <- data[[cue.i]]
-
-    unclassified.cases <- which(is.na(decision[,tree.i]))
-    classified.cases <- which(is.na(decision[,tree.i]) == F)
-
-
-    if(is.character(threshold.i)) {threshold.i <- unlist(strsplit(threshold.i, ","))}
-
-    if(class.i %in% c("numeric", "integer")) {threshold.i <- as.numeric(threshold.i)}
-
-    if(direction.i == "!=") {current.decisions <- (cue.values %in% threshold.i) == F}
-    if(direction.i == "=") {current.decisions <- cue.values %in% threshold.i}
-    if(direction.i == "<") {current.decisions <- cue.values < threshold.i}
-    if(direction.i == "<=") {current.decisions <- cue.values <= threshold.i}
-    if(direction.i == ">") {current.decisions <- cue.values > threshold.i}
-    if(direction.i == ">=") {current.decisions <- cue.values >= threshold.i}
-
-
-    if(exit.i == 0) {classify.now <- current.decisions == F & is.na(decision[,tree.i])}
-    if(exit.i == 1) {classify.now <- current.decisions == T & is.na(decision[,tree.i])}
-    if(exit.i == .5) {classify.now <- is.na(decision[,tree.i])}
-
-
-    decision[classify.now, tree.i] <- current.decisions[classify.now]
-    levelout[classify.now, tree.i] <- level.i
-
-    # Get level stats
-
-    level.i.stats <- classtable(prediction.v = decision[levelout[,tree.i] <= level.i & is.finite(levelout[,tree.i]), tree.i],
-                                criterion.v = criterion.v[levelout[,tree.i] <= level.i & is.finite(levelout[,tree.i])]
-                                )
-
-    level.stats.df.i[level.i, names(level.i.stats)] <- level.i.stats
-
-
-
-    }
-
-  level.stats.ls[[tree.i]] <- level.stats.df.i
-
-  }
-
-  levelstats <- do.call("rbind", args = level.stats.ls)
-
-  # CUMULATIVE TREE STATS
-
-  treestats <- tree.definitions
-  helper <- paste(levelstats$tree, levelstats$level, sep = ".")
-  maxlevs <- paste(rownames(tapply(levelstats$level, levelstats$tree, FUN = which.max)), tapply(levelstats$level, levelstats$tree, FUN = which.max), sep = ".")
-  treestats <- cbind(tree.definitions, levelstats[helper %in% maxlevs, stat.names])
-  rownames(treestats) <- 1:nrow(treestats)
-
-
-
-return(list("decision" = decision,
-            "levelout" = levelout,
-            "levelstats" = levelstats,
-            "treestats" = treestats
-            ))
-
-}
-
 if(is.null(data.train) == F) {
 
 train.results <- apply.tree(data.train, formula, tree.definitions)
@@ -455,6 +393,7 @@ if(is.null(data.train) == T) {
   levelstats.train <- NULL
   treestats.train <- NULL
   tree.auc.train <- NA
+
 }
 
 if(is.null(data.test) == F) {
@@ -465,8 +404,18 @@ decision.test <- test.results$decision
 levelout.test <- test.results$levelout
 levelstats.test <- test.results$levelstats
 treestats.test <- test.results$treestats
+
+if(any(is.na(test.results$treestats$hr)) == T) {
+
+  tree.auc.test <- NA
+
+}
+
+if(all(is.finite(test.results$treestats$hr))) {
+
 tree.auc.test <- auc(hr.v = test.results$treestats$hr, far.v = test.results$treestats$far)
 
+}
 }
 
 if(is.null(data.test) == T) {
@@ -476,6 +425,7 @@ if(is.null(data.test) == T) {
   levelstats.test <- NULL
   treestats.test <- NULL
   tree.auc.test <- NA
+
 }
 
 decision <- list("train" = decision.train, "test" = decision.test)
@@ -493,10 +443,8 @@ rownames(tree.auc) = c("train", "test")
 if(do.lr) {
 
 lr.acc <- lr.pred(formula = formula,
-               data.train = data.train,
-               data.test = data.test
-               )
-
+                 data.train = data.train,
+                 data.test = data.test)
 
 lr.stats <- lr.acc$accuracy
 lr.auc <- lr.acc$auc
@@ -547,8 +495,7 @@ if(do.cart == F) {
 
 auc <- cbind(tree.auc, lr.auc, cart.auc)
 
-output.fft <- list(
-                  "formula" = formula,
+output.fft <- list("formula" = formula,
                   "data" = list("train" = data.train, "test" = data.test),
                   "cue.accuracies" = cue.accuracies,
                   "tree.definitions" = tree.definitions,
