@@ -1,17 +1,22 @@
-# cuerank
-#'   Calculate the accuracy of all cues in a dataframe
+#' Calculate the marginal accuracy of all cues in a dataframe. For each cue, the threshold that maximizes the criterion is selected.
 #'
 #' @param formula A formula specifying a binary criterion as a function of multiple variables
 #' @param data A dataframe containing variables in formula
 #' @param tree.criterion A string indicating how to rank cues. "v" = HR - FAR, "d" = d-prime.
 #' @param numthresh.method A string indicating how to calculate cue splitting thresholds. "m" = median split, "o" = split that maximizes the tree criterion.
-#' @param hr.weight A number between 0 and 1 indicating how much weight to give to increasing hit rates versus avoiding false alarms. 1 means maximizing HR and ignoring FAR, while 0 does the opposite. The default of 0.5 gives equal weight to both.
 #' @param rounding An integer indicating digit rounding for non-integer numeric cue thresholds. The default is NULL which means no rounding. A value of 0 rounds all possible thresholds to the nearest integer, 1 rounds to the nearest .1 (etc.).
 #' @param verbose A logical value indicating whether or not to print ongoing diagnostics
 #' @param cue.rules An optional df specifying how to make decisions for each cue. Must contain columns "cue", "class", "threshold" and "direction"
 #' @importFrom stats median
-#' @return A dataframe containing marginal classification statistics for each cue
+#' @return A dataframe containing best thresholds and marginal classification statistics for each cue
 #' @export
+#' @examples
+#'
+#'  # What are the best thresholds for each cue in the mushrooms dataset?
+#'  mushrooms.cues <- cuerank(formula = poisonous ~.,
+#'                            data = mushrooms)
+#'
+#'
 #'
 
 
@@ -19,7 +24,6 @@ cuerank <- function(formula = NULL,
                     data = NULL,
                     tree.criterion = "v",
                     numthresh.method = "o",
-                    hr.weight = .5,
                     rounding = NULL,
                     verbose = F,
                     cue.rules = NULL
@@ -30,18 +34,6 @@ cuerank <- function(formula = NULL,
 # TESTING GROUNDS
 # -----
 
-  # formula <- diagnosis ~.
-  # data <- heartdisease[1:75,]
-  #
-  # cue.df <- heartdisease
-  # criterion.v <- heartdisease$diagnosis
-  # tree.criterion <- "v"
-  # numthresh.method <- "o"
-  # hr.weight <- .5
-  # correction <- .25
-  # rounding <- 2
-  # cue.rules <- NULL
-
 
   # EXTRACT FORMULA VARIABLES
 
@@ -56,16 +48,6 @@ cuerank <- function(formula = NULL,
 
   }
 
-  #
-  #
-  #
-  # cue.df = fds.63.cues
-  # criterion.v = fds.63.crit
-  # tree.criterion = "v"
-  # hr.weight = .5
-  # correction = 0
-  #
-
 
 # GLOBAL VARIABLES (could be updated later)
 
