@@ -5,20 +5,16 @@ library(FFTrees)
 head(heartdisease)
 
 ## ------------------------------------------------------------------------
-set.seed(100)
+set.seed(100) # For replication
 samples <- sample(c(T, F), size = nrow(heartdisease), replace = T)
 heartdisease.train <- heartdisease[samples,]
 heartdisease.test <- heartdisease[samples == 0,]
 
 ## ------------------------------------------------------------------------
-heart.fft <- FFTrees(
-  formula = diagnosis ~.,
-  data = heartdisease.train,
-  data.test = heartdisease.test
-  )
-
-## ------------------------------------------------------------------------
-class(heart.fft)
+heart.fft <- FFTrees(formula = diagnosis ~.,
+                    data = heartdisease.train,
+                    data.test = heartdisease.test
+                    )
 
 ## ------------------------------------------------------------------------
 names(heart.fft)
@@ -34,24 +30,24 @@ showcues(heart.fft,
          main = "Heartdisease Cue Accuracy")
 
 ## ------------------------------------------------------------------------
-heart.fft$fft.stats
-
-## ---- eval = F-----------------------------------------------------------
-#  summary(heart.fft)  # Same thing as heart.fft$fft.stats
+heart.fft$tree.definitions
 
 ## ------------------------------------------------------------------------
-heart.fft$auc
+heart.fft$tree.stats$train
 
 ## ------------------------------------------------------------------------
-heart.fft$decision.train[1:5,]
+heart.fft$decision$train[1:5,]
 
 ## ------------------------------------------------------------------------
-heart.fft$levelout.train[1:5,]
+heart.fft$levelout$test[1:5,]
 
 ## ------------------------------------------------------------------------
-heart.as.fft <- FFTrees(formula = diagnosis ~ age + sex,
-                    data = heartdisease
-                    )
+heart.fft <- predict(heart.fft,
+                     data.test = heartdisease[1:50,]
+                     )
+
+## ------------------------------------------------------------------------
+heart.fft
 
 ## ---- fig.width = 6, fig.height = 6--------------------------------------
 plot(heart.fft,
@@ -59,3 +55,6 @@ plot(heart.fft,
      decision.names = c("Healthy", "Disease")
      )
 
+## ----fig.width = 5, fig.height = 5---------------------------------------
+showcues(heart.fft)
+
